<?php
require_once("cwfUI.inc.php");

class EventFormUI extends cwfUI {
  protected static $accessRight = "edit_fees";
  protected static $dataClass = "EventForm";
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // initialize
  public function __construct(DbConnection $DB, $eventId=null) {
    parent::__construct();
    $this->initialize();

    if(!$eventId && !isset($_SESSION['event'])) {
      $this->error = _("No event selected.");
    }
    else {
      if($eventId)
        $this->data->setEventId($eventId);
      else
        $this->data->setEventId($_SESSION['event']->event_id);
      $this->data->readData($DB);
    }
  }
  
  protected function initialize() {
    parent::initialize();
    $this->title = _("Event Forms");
    $this->header .= '  <script src="'.KDbConfig::getCwfHttpPath().'k_db/js/kdb_eventforms.js.php" type="text/javascript"></script>'."\n";
    $this->header .= '  <link rel="stylesheet" href="'.KDbConfig::getCwfHttpPath().'k_db/css/eventforms.css" type="text/css">'."\n";
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // handle data
  public function getPostBackXML(DbConnection $DB, $action) {
    $xml = "";
    switch ($action) {
      case "updateForm":
        switch($_POST['formName']) {
          case "kdb_copy_form":
            $xml = "  <replaceHTMLElement id=\"#dialog_copy_form .dialog_preview\"><![CDATA[\n";
            $preview = new UserBookingUI($DB, $_POST['id']);
            ob_start();
            $preview->getHTMLView($DB, true, 1);
            $xml .= "  <div class=\"dialog_preview\">\n";
            $xml .= ob_get_contents();
            ob_end_clean(); 
            $xml .= "  </div>\n";
            $xml .= "]]>\n";
            $xml .= "  </replaceHTMLElement>\n";
            break;
          case "kdb_form":
            $xml = "  <replaceHTMLElement id=\"#kdb_event_fees\"><![CDATA[\n";
            $this->data = new static::$dataClass();
            $this->data->setEventId($_POST['id']);
            $this->data->readData($DB);
            ob_start();
            $this->getEventFeeHTML();
            $xml .= "<div id=\"kdb_event_fees\">\n";
            $xml .= ob_get_contents();
            ob_end_clean(); 
            $xml .= "</div>\n";
            $xml .= "]]>\n";
            $xml .= "  </replaceHTMLElement>\n";
        }
        break;
      case "save":
        $xml = "  <replaceHTMLElement id=\"#kdb_event_fees\"><![CDATA[\n";
        ob_start();
        $this->getEventFeeHTML();
        $xml .= "<div id=\"kdb_event_fees\">\n";
        $xml .= ob_get_contents();
        ob_end_clean(); 
        $xml .= "</div>\n";
        $xml .= "]]>\n";
        $xml .= "  </replaceHTMLElement>\n";
        break;
      default:
        $xml = parent::getPostBackXML($DB, $action);
    }
    return $xml;
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // Database operations
  public function saveForm(DbConnection $DB) {
    if(parent::saveForm($DB)) {
      if (isset($_SESSION['event']) && $_SESSION['event']->event_id==$this->data->event_id)
        $_SESSION['event']->readData($DB, array("event_id"=>$_SESSION['event']->event_id));
      return 1;
    }
    return 0;
  }  
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // output
  static public function getHTMLOptionGroupHeader($groupId="", $group=null) {
    return "<div class=\"kdb_option_group\">
  <div class=\"kdb_eventoption_formsettings\">
    <p><input type=\"checkbox\" id=\"required[$groupId]\" name=\"required[$groupId]\" value=\"1\"".((isset($group)&&$group->required) ? " checked" : "")."></p>
  </div>
  <div class=\"kdb_option_group_details\">\n";
  }
  
  static public function getHTMLOptionGroup($groupId="", EventOptionsGroup $group=null) {
    return "    <p>
      <input type=\"hidden\" name=\"event_option_group_id[$groupId]\" id=\"event_option_group_id[$groupId]\" value=\"".((isset($group)) ? $group->event_option_group_id : "")."\">
      <input type=\"text\" id=\"group_name[$groupId]\" name=\"group_name[$groupId]\" value=\"".((isset($group)) ? $group->group_name : "")."\" placeholder=\""._("Option Group")."\">
      <span class=\"display_add_info add_info_closed\" onClick=\"kdbShowAddInfo($(this));\"></span>
    </p>
    <div class=\"kdb_option_group_config\" style=\"display:none;\">
      <p>
        <label for=\"group_type[$groupId]\">"._("Group type").":</label>
        <input type=\"hidden\" name=\"group_type[$groupId]\" id=\"group_type[$groupId]\" value=\"".((isset($group)) ? $group->group_type : "")."\">
        <select name=\"group_type_display\" disabled>
          <option value=\"-1\">"._("Choose group type")."</option>
          <option value=\"".OPTION_GROUP_FEES."\"".((isset($group)&&$group->group_type==OPTION_GROUP_FEES) ? " selected" : "").">"._("Event fees")."</option>
          <option value=\"".OPTION_GROUP_TICKETS."\"".((isset($group)&&$group->group_type==OPTION_GROUP_TICKETS) ? " selected" : "").">"._("Tickets")."</option>
          <option value=\"".OPTION_GROUP_ADDINFO."\"".((isset($group)&&$group->group_type==OPTION_GROUP_ADDINFO) ? " selected" : "").">"._("Additional information")."</option>
        </select>
      </p>
      <p>
        <label for=\"exclusive[$groupId]\">"._("Exclusive").":</label>
        <input type=\"checkbox\" id=\"exclusive[$groupId]\" name=\"exclusive[$groupId]\" value=\"1\" onChange=\"kdbChangeExclusive(\$(this));\"".
            ((isset($group)&&!in_array($group->group_type, array(OPTION_GROUP_FEES, OPTION_GROUP_TICKETS))) ? " disabled" : "").
            ((isset($group)&&$group->exclusive) ? " checked" : "").">
      </p>
      <p>
        <label for=\"allow_changes[$groupId]\">"._("Allow changes").":</label>
        <input type=\"checkbox\" id=\"allow_changes[$groupId]\" name=\"allow_changes[$groupId]\" value=\"1\"".
            ((isset($group)&&$group->group_type!=OPTION_GROUP_ADDINFO) ? " disabled" : "").
            ((isset($group)&&$group->allow_changes) ? " checked" : "").">
      </p>
      <p".($_SESSION['event']->enable_waitlist ? "" : " style=\"display:none;\"").">
        <label for=\"enable_waitlist[$groupId]\">"._("Enable waiting list").":</label>
        <input type=\"checkbox\" id=\"enable_waitlist[$groupId]\" name=\"enable_waitlist[$groupId]\" value=\"1\"".
            ((isset($group)&&!in_array($group->group_type, array(OPTION_GROUP_FEES))) ? " disabled" : "").
            ((isset($group)&&$group->enable_waitlist) ? " checked" : "").">
      </p>
    </div>
    <p><textarea class=\"kdb_option_group\" id=\"description[$groupId]\" name=\"description[$groupId]\" placeholder=\""._("Optional description")."\">".
            ((isset($group)) ? $group->description : "")."</textarea></p>\n";
  }

  static public function getHTMLEventOption($type, $groupId="", $optionId="", EventOption $option=null) {
    switch ($type) {
      case OPTION_GROUP_FEES:
        $s = "    <div class=\"kdb_eventoption\">
      <div class=\"kdb_eventoption_details\">
        <input type=\"hidden\" name=\"event_option_id[$groupId][$optionId]\" id=\"event_option_id[$groupId][$optionId]\" value=\"".((isset($option)) ? $option->event_option_id : "")."\">&nbsp;&nbsp;&nbsp;
        <input type=\"text\" name=\"event_option[$groupId][$optionId]\" id=\"event_option[$groupId][$optionId]\" value=\"".((isset($option)) ? $option->event_option : "")."\">
        (<input type=\"text\" name=\"person_limit[$groupId][$optionId]\" id=\"person_limit[$groupId][$optionId]\" value=\"".((isset($option)) ? $option->person_limit : "")."\">)
      </div>
      <div class=\"kdb_fee_details\">\n";
        if(isset($option)) {
          $feeKeys = array_keys($option->eventFees);
          $lastFee = array_pop($feeKeys);
          foreach ($option->eventFees as $feeId => $fee) {
            if($fee->delete) continue;
            if($feeId!=$lastFee)
              $s .= preg_replace("~\s*<button.*kdbDeadlineAdd.*~", "", self::getHTMLFee($groupId, $optionId, $feeId, $fee));
            else
              $s .= self::getHTMLFee($groupId, $optionId, $feeId, $fee);
          }
        }
        else
          $s .= self::getHTMLFee();
        $s .= "      </div>\n";
        $s .= "    </div>\n";
        return $s;
        break;
        
      case OPTION_GROUP_TICKETS:
        $s = "    <div class=\"kdb_eventoption\">
      <div class=\"kdb_eventoption_details\">
        <input type=\"hidden\" name=\"event_option_id[$groupId][$optionId]\" id=\"event_option_id[$groupId][$optionId]\" value=\"".((isset($option)) ? $option->event_option_id : "")."\">&nbsp;&nbsp;&nbsp;
        <input type=\"text\" name=\"event_option[$groupId][$optionId]\" id=\"event_option[$groupId][$optionId]\" value=\"".((isset($option)) ? $option->event_option : "")."\">
        (<input type=\"text\" name=\"person_limit[$groupId][$optionId]\" id=\"person_limit[$groupId][$optionId]\" value=\"".((isset($option)) ? $option->person_limit : "")."\">)
      </div>
      <div class=\"kdb_fee_details\">
        <div>\n";
        if(isset($option)) {
          $feeKeys = array_keys($option->eventFees);
          $feeId = array_shift($feeKeys);
          $s .= "        <input type=\"hidden\" name=\"event_fee_id[$groupId][$optionId][$feeId]\" id=\"event_fee_id[$groupId][$optionId][$feeId]\" value=\"".($feeId ? $feeId : "")."\">
        ".KDbConfig::getCurrency()."<input type=\"text\" name=\"event_fee[$groupId][$optionId][$feeId]\" id=\"event_fee[$groupId][$optionId][$feeId]\" class=\"formsedit_right\" size=\"5\" value=\"".((isset($option->eventFees[$feeId])) ? $option->eventFees[$feeId]->event_fee : "")."\">.-- ";
        }
        else
          $s .= "        <input type=\"hidden\" name=\"event_fee_id[$groupId][$optionId][]\" id=\"event_fee_id[$groupId][$optionId][]\" value=\"\">
        ".KDbConfig::getCurrency()."<input type=\"text\" name=\"event_fee[$groupId][$optionId][]\" id=\"event_fee[$groupId][$optionId][]\" class=\"formsedit_right\" size=\"5\" value=\"\">.-- ";
        $s .= "          <select class=\"no_tickets\" name=\"dummy\" disabled><option></option></select> 
          <input type=\"text\" name=\"booking_limit[$groupId][$optionId]\" id=\"booking_limit[$groupId][$optionId]\" value=\"".((isset($option)) ? $option->booking_limit : "")."\">
          <button onClick=\"kdbDeadlineDel($(this));\" type=\"button\"><img src=\"../../k_db/img/icons/delete.png\" alt=\"Delete\" height=\"12\" width=\"12\"></button>
        </div>
      </div>
    </div>\n";
        return $s;
        break;
        
      case OPTION_GROUP_ADDINFO:
        $hideList = ((isset($option)&&$option->option_type==EVENT_OPTION_SELECT) ? "" : " style=\"display:none;\"");
        return "    <div class=\"kdb_eventoption\">
      <div class=\"kdb_eventoption_details\">
        <input type=\"hidden\" name=\"event_option_id[$groupId][$optionId]\" id=\"event_option_id[$groupId][$optionId]\" value=\"".((isset($option)) ? $option->event_option_id : "")."\">&nbsp;&nbsp;&nbsp;
        <input type=\"text\" name=\"event_option[$groupId][$optionId]\" id=\"event_option[$groupId][$optionId]\" value=\"".((isset($option)) ? $option->event_option : "")."\">
      </div>
      <div class=\"kdb_fee_details\">
        <div>
          <select id=\"option_type[$groupId][$optionId]\" name=\"option_type[$groupId][$optionId]\">
            <option value=\"".EVENT_OPTION_TEXT."\"".((isset($option)&&$option->option_type==EVENT_OPTION_TEXT) ? " selected" : "").">"._("Text (single line)")."</option>
            <option value=\"".EVENT_OPTION_TEXT_MULTILINE."\"".((isset($option)&&$option->option_type==EVENT_OPTION_TEXT_MULTILINE) ? " selected" : "").">"._("Text (mulitiline)")."</option>
            <option value=\"".EVENT_OPTION_DATE."\"".((isset($option)&&$option->option_type==EVENT_OPTION_DATE) ? " selected" : "").">"._("Date")."</option>
            <option value=\"".EVENT_OPTION_NUMBER_INT."\"".((isset($option)&&$option->option_type==EVENT_OPTION_NUMBER_INT) ? " selected" : "").">"._("Number (integer)")."</option>
            <option value=\"".EVENT_OPTION_NUMBER_DEC."\"".((isset($option)&&$option->option_type==EVENT_OPTION_NUMBER_DEC) ? " selected" : "").">"._("Number (decimal)")."</option>
            <option value=\"".EVENT_OPTION_SELECT."\"".((isset($option)&&$option->option_type==EVENT_OPTION_SELECT) ? " selected" : "").">"._("Select list")."</option>
          </select>
          <input type=\"text\" name=\"list[$groupId][$optionId]\" id=\"list[$groupId][$optionId]\" value=\"".((isset($option)) ? implode(",", $option->list) : "")."\" placeholder=\""._("Comma separated list")."\"{$hideList}>
          <button onClick=\"kdbDeadlineDel($(this));\" type=\"button\"><img src=\"../../k_db/img/icons/delete.png\" alt=\"Delete\" height=\"12\" width=\"12\"></button>
        </div>
      </div>
    </div>\n";
        break;
    }
  }

  static public function getHTMLFee($groupId="", $optionId="", $feeId="", EventFee $fee=null) {
    return "        <div class=\"kdb_deadline\">
          <input type=\"hidden\" name=\"event_fee_id[$groupId][$optionId][$feeId]\" id=\"event_fee_id[$groupId][$optionId][$feeId]\" value=\"".((isset($fee)) ? $fee->event_fee_id : "")."\">
          <input type=\"radio\" name=\"dummy\" value=\"\" disabled> 
          ".KDbConfig::getCurrency()."<input type=\"text\" name=\"event_fee[$groupId][$optionId][$feeId]\" id=\"event_fee[$groupId][$optionId][$feeId]\" class=\"formsedit_right\" size=\"5\" value=\"".((isset($fee)) ? $fee->event_fee : "")."\">.-- "._("until")."
          <input type=\"text\" name=\"deadline[$groupId][$optionId][$feeId]\" id=\"deadline[$groupId][$optionId][$feeId]\" class=\"formsedit_left\" size=\"10\" maxlength=\"10\" value=\"".((isset($fee)) ? CWFTools::dateISO2Local($fee->deadline, getenv("LC_ALL")) : "")."\" placeholder=\"".CWFTools::dateISO2Local("2000-12-31", getenv("LC_ALL"))."\">
          <button onClick=\"kdbDeadlineDel($(this));\" type=\"button\"><img src=\"../../k_db/img/icons/delete.png\" alt=\"Delete\" height=\"12\" width=\"12\"></button>
          <button onClick=\"kdbDeadlineAdd($(this));\" type=\"button\"><img src=\"../../k_db/img/icons/add.png\" alt=\"New\" height=\"12\" width=\"12\"></button>
        </div>\n";
  }

  static public function getHTMLOptionGroupFooter($groupType="\$type\$") {
    return "    <input type=\"button\" id=\"kdb_add_option\" name=\"kdb_add_option\" value=\""._("Add option")."\" onClick=\"kdbAddOption($(this), {$groupType});\">
  </div>
</div>\n";
  }
  
  private function getEventFeeHTML() {
    foreach ($this->data->eventForm as $groupId => $group) {
      if($group->delete) continue;
      echo self::getHTMLOptionGroupHeader($groupId, $group);
      echo self::getHTMLOptionGroup($groupId, $group);
      foreach ($group->eventOptions as $optionId => $option) {
        if($option->delete) continue;
        if($group->exclusive)
            echo self::getHTMLEventOption($group->group_type, $groupId, $optionId, $option);
        else
            echo str_replace("radio", "checkbox", self::getHTMLEventOption($group->group_type, $groupId, $optionId, $option));
      }
      echo self::getHTMLOptionGroupFooter($group->group_type);
    }
  }
  
  public function getHTML(DbConnection $DB) {
?>
<form id="kdb_form" action="" method="post" enctype="multipart/form-data">
<div id="side_panel"><div id="side_panel_label"><h3 class="nomargin">Preview</h3></div>
  <div id="side_panel_content">
  </div>
</div>

<div class="form_controls_top">
<p>
  <input type="submit" id="kdb_save" name="kdb_save" value="<?=_("Save")?>" onClick="kdbSaveEntry('EventFormUI', 'save'); return false;">
  <input type="button" id="kdb_copy" name="kdb_copy" value="<?=_("Copy form")?>" onClick="kdbShowCopyDialog(); return false;">
</p>
</div>

<h3 class="first"><?=_("Book program")?></h3>

<input type="hidden" id="event_id" name="event_id" class="id" value="<?= $this->data->event_id ?>">

<span id="tt_required" class="tooltip below"><?= _("The user has to select one option in this option group.") ?></span>
<span id="tt_option_group_name" class="tooltip below"><?=_("The name of the group is used as a heading before the options.")?></span>
<span id="tt_group_type" class="tooltip below"><?= _("A group of type 'event fees' can only contain fees. A group of type 'tickets' can only contain fees, but each fee can be booked multiple times. A group of type 'additional information' can contain different form elements (e. g. text or date fields).") ?></span>
<span id="tt_exclusive" class="tooltip below"><?=_("Only one of the items in this group can be selected. This option is only available for fees.")?></span>
<span id="tt_allow_changes" class="tooltip below"><?=_("The user can change the data in this group after registration. This option is not available for fees.")?></span>
<span id="tt_enable_waitlist" class="tooltip"><?=_("Allow users to book booked out event options. They will be added to a waiting list for this event option.")?></span>
<span id="tt_event_option" class="tooltip below"><?=_("Event options are for example 'participant', 'student', 'trip to ...'.")?></span>
<span id="tt_person_limit" class="tooltip below"><?=_("Maximum number of participants")?></span>
<span id="tt_booking_limit" class="tooltip below"><?=_("Maximum number of tickets that can be booked in one order")?></span>
<span id="tt_event_fee" class="tooltip below"><?=_("The amount which has to been paid until the deadline (deadline not available for tickets). After the deadline this eventoption is not available anymore or the next amount has to be paid (until the corresponding deadline).")?></span>
<span id="tt_deadline" class="tooltip below"><?=_("Deadline, e.g. ").CWFTools::dateISO2Local("2000-12-31", getenv("LC_ALL"))?></span>

<div id="kdb_required_warning" style="display:none;">
  <?=_("No mandatory fee chosen yet!")?><br>
  &darr;
</div>

<div id="kdb_event_fees">
<?php
    $this->getEventFeeHTML();
?>
</div>

<br style="clear:both;">
<p>
<input type="button" id="kdb_add_option_group" name="kdb_add_option_group" value="<?=_("Add group")?>" onClick="$('#dialog_option_group').show();">
</p>

<div class="form_controls_bottom">
<p>
  <input type="submit" id="kdb_save2" name="kdb_save" value="<?=_("Save")?>" onClick="kdbSaveEntry('EventFormUI', 'save'); return false;">
</p>
</div>
</form>

<div id="dialog_option_group" class="dialog_container">
<div class="dialog_columns">
  <div class="dialog withpreview">
    <h3 class="first"><?=_("Add option group")?></h3>
  
    <p>
      <label for="dialog_option_group_name"><?=_("Name")?>:</label>
      <input type="text" id="dialog_option_group_name" name="dialog_option_group_name" value="">
        <span id="tt_dialog_option_group_name" class="tooltip below"><?=_("The name of the group is used as a heading before the options.")?></span>
    </p>
    
    <p>
      <label for="dialog_option_group_type"><?=_("Group type")?>:</label>
      <select id="dialog_option_group_type" name="dialog_option_group_type">
        <option value="-1"><?=_("Choose option group")?></option>
        <option value="<?= OPTION_GROUP_FEES ?>"><?=_("Event fees")?></option>
        <option value="<?= OPTION_GROUP_TICKETS ?>"><?=_("Tickets")?></option>
        <option value="<?= OPTION_GROUP_ADDINFO ?>"><?=_("Additional information")?></option>
      </select>
      <span id="tt_dialog_option_group_type" class="tooltip below"><?= _("A group of type 'event fees' can only contain fees. A group of type 'tickets' can only contain fees, but each fee can be booked multiple times. A group of type 'additional information' can contain different form elements (e. g. text or date fields).") ?></span>
    </p>
    
    <p>
      <label for="dialog_exclusive"><?=_("Exclusive")?>:</label>
      <input type="checkbox" id="dialog_exclusive" name="dialog_exclusive" value="1" disabled>
        <span id="tt_dialog_exclusive" class="tooltip below"><?=_("Only one of the items in this group can be selected. This option is only available for fees.")?></span>
    </p>
    
    <p>
      <label for="dialog_allow_changes"><?=_("Allow changes")?>:</label>
      <input type="checkbox" id="dialog_allow_changes" name="dialog_allow_changes" value="1" disabled>
        <span id="tt_dialog_allow_changes" class="tooltip below"><?=_("The user can change the data in this group after registration. This option is not available for fees.")?></span>
    </p>
<?php
    if($_SESSION['event']->enable_waitlist) {
?> 
    <p>
      <label for="dialog_enable_waitlist"><?=_("Enable waiting list")?>:</label>
      <input type="checkbox" id="dialog_enable_waitlist" name="dialog_enable_waitlist" value="1" disabled>
        <span id="tt_dialog_enable_waitlist" class="tooltip below"><?=_("Allow users to book booked out event options. They will be added to a waiting list for this event option.")?></span>
    </p>
<?php 
    }
?>
  </div>
  <div class="dialog_preview">
    <h3 id="dialog_option_group_name_preview" class="first"></h3>
    <div id="dialog_event_fee_preview" style="display:none;">
      <p>
        <label for="eventoption1_preview"><?=_("Event fee 1")?></label>
        <input type="checkbox" name="eventoption1_preview" value="1" disabled><span class="form_element">&nbsp;15 <?=KDbConfig::getCurrency()?></span>
      </p>
      <p>
        <label for="eventoption2_preview"><?=_("Event fee 2")?></label>
        <input type="checkbox" name="eventoption2_preview" value="1" disabled><span class="form_element">&nbsp;25 <?=KDbConfig::getCurrency()?></span>
      </p>
    </div>
    <div id="dialog_tickets_preview" style="display:none;">
      <div id="dialog_tickets_preview_nexcl">
        <p>
          <label for="eventoption3_preview" style="width:150px;"><?=_("Ticket category 1")?></label>
          <span class="form_element">15&nbsp;<?=KDbConfig::getCurrency()?>&nbsp;</span><select name="eventoption3_preview" class="no_tickets" disabled><option></option></select>
        </p>
        <p>
          <label for="eventoption4_preview" style="width:150px;"><?=_("Ticket category 2")?></label>
          <span class="form_element">25&nbsp;<?=KDbConfig::getCurrency()?>&nbsp;</span><select name="eventoption4_preview" class="no_tickets" disabled><option></option></select>
        </p>
      </div>
      <div id="dialog_tickets_preview_excl" style="display:none;">
        <p>
          <span class="form_element"><select name="eventoption5_preview" disabled><option><?=_("Ticket category 1")?>&nbsp;(15&nbsp;<?=KDbConfig::getCurrency()?>)</option></select></span>
          <span class="form_element"><select name="eventoption6_preview" class="no_tickets" disabled><option></option></select></span>
        </p>
      </div>
    </div>
    <div id="dialog_additional_information_preview" style="display:none;">
      <p>
        <label for="eventoption7_preview"><?=_("Additional Info 1:")?></label>
        <input type="text" name="eventoption7_preview" value="" readonly>
      </p>
      <p>
        <label for="eventoption8_preview"><?=_("Additional Info 2:")?></label>
        <span class="form_element"><textarea name="eventoption8_preview" readonly></textarea></span>
      </p>
    </div>
  </div>  
  <div class="form_controls_bottom">
    <input type="button" id="kdb_dialog_ok" name="kdb_dialog_ok" value="<?=_("OK")?>" onClick="kdbAddOptionGroup($('#dialog_option_group'));">
    <input type="button" id="kdb_dialog_cancel" name="kdb_dialog_cancel" value="<?=_("Cancel")?>" onClick="kdbHideDialog();">
  </div>
</div>
</div>

<form id="kdb_copy_form" action="" method="post" enctype="multipart/form-data">
<div id="dialog_copy_form" class="dialog_container">
<div class="dialog_columns">
  <div class="dialog withpreview">
    <h3 class="first"><?=_("Copy event form")?></h3>
  
    <p>
      <label for="dialog_event_list"><?= _("Events") ?>:</label>
      <select id="dialog_event_list" name="dialog_event_list" class="select_id" onChange="kdbUpdateForm(this, 'EventFormUI', 'kdb_copy_form');" size="10">
    <?php
        $events = Event::readList($DB);
        foreach ($events as $event)
          echo "    <option value=\"{$event['id']}\">{$event['name']}</option>\n";
    ?>
      </select>
    </p>
  </div>
  <div class="dialog_preview">
  </div>  
  <div class="form_controls_bottom">
    <input type="button" id="kdb_dialog_ok" name="kdb_dialog_ok" value="<?=_("OK")?>" onClick="kdbEventFormCopy(this); $('#dialog_copy_form').hide();">
    <input type="button" id="kdb_dialog_cancel" name="kdb_dialog_cancel" value="<?=_("Cancel")?>" onClick="$('#dialog_copy_form').hide();">
  </div>
</div>
</div>
</form>

<?php
  }
}

?>