<?php
require_once ("icwfData.inc.php");
require_once ("FormValidation.inc.php");

class UserBooking implements icwfData {
	private static $noExport = array("form");
	private static $notInArray = array("validation","form","bookingCheck");
	private $validation;
	public $form;
	private $booking_id;
	private $user_id;
	private $event_id;
	private $booking_date;
	private $change_log;
	private $bookedOptions;
	private $bookingCheck;
	
	// ///////////////////////////////////////////////////////////////////////////////////////////////
	// initialize
	private function initialize() {
		foreach ($this as $key => $value)
			if ($key == "bookedOptions")
				$this->$key = array();
			else
				$this->$key = null;
	}

	public function __construct(FormValidation $validation = null) {
		$this->initialize();
		
		$this->form = new EventForm();
		$this->bookingCheck = new UserBookingCheck();
		
		if (!$validation)
			$this->validation = new FormValidation(array(), array());
		else
			$this->validation = $validation;
		
		if (isset($_SESSION['user'])) $this->user_id = $_SESSION['user']->user_id;
	}
	
	// ///////////////////////////////////////////////////////////////////////////////////////////////
	// get values
	public function __get($name) {
		if ($name == "id") $name = "booking_id";
		if (array_key_exists($name, get_class_vars(get_class())) && !in_array($name, self::$noExport)) return $this->$name;
		
		return null;
	}

	public function getIDName() {
		return "booking_id";
	}

	public function toArray() {
		$array = array();
		foreach ($this as $key => $value) {
			if (!in_array($key, self::$notInArray)) {
				if ($key == "bookedOptions") {
					foreach ($value as $optionId => $option) {
						switch ($option->event_group_type) {
							case OPTION_GROUP_TICKETS :
								foreach ($this->form->eventForm as $findGroup)
									foreach ($findGroup as $findOption)
										if ($findOption->event_option_id == $option->event_option_id) break 2;
								if ($findGroup->exclusive) {
									$array["event_option_g[" . $findGroup->event_option_group_id . "]"] = $option->event_option_id;
									$array["no_tickets[" . $findGroup->event_option_group_id . "]"] = $option->getValue(true);
								}
								else {
									$array["event_option[" . $option->event_option_id . "]"] = $option->getValue(true);
								}
								break;
							default :
								$array["event_option[" . $option->event_option_id . "]"] = $option->getValue(true);
								$array["waitlist_event_option[" . $option->event_option_id . "]"] = $option->waitlist;
								break;
						}
					}
				}
				else
					$array[$key] = $value;
			}
		}
		return $array;
	}

	public function getPostBackData() {
		return array($this->getIDName() => $this->id);
	}

	public function isWaitlisted() {
		foreach ($this->bookedOptions as $bookedOption)
			if ($bookedOption->waitlist) return true;
		
		return false;
	}
	
	// ///////////////////////////////////////////////////////////////////////////////////////////////
	// set values
	public function setUserId($userId) {
		$this->user_id = $userId;
	}

	public function setEventId($DB, $eventId) {
		$this->form->setEventId($eventId);
		$this->form->readData($DB);
		$this->event_id = $eventId;
	}

	public function unsetBookingId() {
		if (isset($_SESSION['admin'])) $this->booking_id = null;
	}

	public function setValidation(FormValidation $validation) {
		$this->validation = $validation;
	}

	public function fromArray($array, $force = false) {
		if (!isset($_SESSION['admin'])) $force = false;
		foreach ($this as $key => $value) {
			switch ($key) {
				case "validation" :
				case "booking_date" :
				case "bookingCheck" :
				case "form" :
					break;
				
				case "user_id" :
					if (!isset($_SESSION["user"])) {
						if (isset($array[$key]) && !is_array($array[$key])) {
							if (preg_match("~^[0-9]+$~", $array[$key]))
								$this->$key = $array[$key];
							else
								$this->$key = null;
						}
						else if (!isset($array[$key])) $this->$key = null;
					}
					break;
				case "event_id" :
					if (!isset($_SESSION["event"])) {
						if (isset($array[$key]) && preg_match("~^[0-9]+$~", $array[$key]))
							$this->$key = $array[$key];
						else
							$this->$key = null;
					}
					break;
				case "booking_id" :
					if (isset($array[$key]) && preg_match("~^[0-9]+$~", $array[$key]))
						$this->$key = $array[$key];
					else
						$this->$key = null;
					break;
				
				case "bookedOptions" :
					foreach ($this->form->eventForm as $groupId => $group) {
						if ($group->group_type == OPTION_GROUP_TICKETS && $group->exclusive) {
							if (isset($array['event_option_g'][$group->event_option_group_id]) && preg_match('~^[0-9]+$~', $array['event_option_g'][$group->event_option_group_id])) {
								$option = $group->eventOptions[$array['event_option_g'][$group->event_option_group_id]];
								$bookingOption = $this->fromArrayTickets($group, $option, $array, $force);
								if ($bookingOption == null) continue;
							}
							else
								continue;
							$bookingOption->event_group_type = $group->group_type;
							$bookingOption->event_option_id = $option->event_option_id;
							$this->bookedOptions[$option->event_option_id] = $bookingOption;
						}
						else {
							foreach ($group->eventOptions as $optionId => $option) {
								if (!$this->booking_id || ($group->group_type == OPTION_GROUP_ADDINFO && $group->allow_changes) || $force) {
									switch ($group->group_type) {
										case OPTION_GROUP_FEES :
											$bookingOption = $this->fromArrayFees($group, $option, $array, $force);
											if ($bookingOption == null) continue 2;
											break;
										case OPTION_GROUP_TICKETS :
											$bookingOption = $this->fromArrayTickets($group, $option, $array, $force);
											if ($bookingOption == null) continue 2;
											break;
										case OPTION_GROUP_ADDINFO :
											$bookingOption = $this->fromArrayAddInfo($group, $option, $array);
											break;
										default :
											$bookingOption = new UserBookingOption();
											break;
									}
									$bookingOption->event_group_type = $group->group_type;
									$bookingOption->event_option_id = $option->event_option_id;
									
									$this->bookedOptions[$option->event_option_id] = $bookingOption;
								}
							}
						}
					}
					foreach ($this->form->eventForm as $groupId => $group) {
						if (in_array($group->group_type, array(OPTION_GROUP_FEES,OPTION_GROUP_TICKETS)) && $group->exclusive) {
							$found = false;
							foreach ($group->eventOptions as $option)
								if (isset($this->bookedOptions[$option->event_option_id])) $found = true;
							
							if (!$found && isset($array["event_option_g"][$group->event_option_group_id])) unset($array["event_option_g"][$group->event_option_group_id]);
							if (!$found && isset($array["no_tickets"][$group->event_option_group_id])) unset($array["no_tickets"][$group->event_option_group_id]);
						}
					}
					break;
				
				default :
					$this->$key = null;
					break;
			}
		}
		return $this->validation->validate($array);
	}

	private function fromArrayFees(EventOptionsGroup $group, EventOption $option, &$array, $force) {
		$bookingOption = new UserBookingOption();
		if ($group->exclusive) {
			$elementName = "event_option_g";
			$elementIdx = $group->event_option_group_id;
		}
		else {
			$elementName = "event_option";
			$elementIdx = $option->event_option_id;
		}
		if (isset($array[$elementName][$elementIdx]) && $option->feeExists($array[$elementName][$elementIdx])) {
			if ($option->person_limit > 0 && $option->person_limit <= $option->no_of_bookings && !$group->enable_waitlist && !$force) {
				if ($elementName == "event_option") unset($array[$elementName][$elementIdx]);
				return null;
			}
			$bookingOption->event_fee_id = $array[$elementName][$elementIdx];
			if ($force)
				$bookingOption->waitlist = ((isset($array["waitlist_" . $elementName][$elementIdx]) && $array["waitlist_" . $elementName][$elementIdx]) ? 1 : 0);
			else
				$bookingOption->waitlist = (($option->person_limit > 0 && $option->person_limit <= $option->no_of_bookings) ? 1 : 0);
			$bookingOption->value_int = 1;
		}
		else if ($force) {
			$bookingOption->event_fee_id = null;
			$bookingOption->value_int = 0;
		}
		else {
			if (isset($array[$elementName][$elementIdx]) && $elementName == "event_option") unset($array[$elementName][$elementIdx]);
			return null;
		}
		
		$bookingOption->changeAllowed = 0;
		
		return $bookingOption;
	}

	private function fromArrayTickets(EventOptionsGroup $group, EventOption $option, &$array, $force) {
		$bookingOption = new UserBookingOption();
		if ($group->exclusive) {
			$elementName = "no_tickets";
			$elementIdx = $group->event_option_group_id;
		}
		else {
			$elementName = "event_option";
			$elementIdx = $option->event_option_id;
		}
		if (isset($array[$elementName][$elementIdx]) && preg_match('~^[1-9][0-9]*$~', $array[$elementName][$elementIdx])) {
			if ($option->person_limit > 0 && $option->person_limit <= $option->no_of_bookings && !$group->enable_waitlist && !$force) {
				if ($elementName == "event_option") unset($array[$elementName][$elementIdx]);
				return null;
			}
			$bookingOption->event_fee_id = $option->getCurrentFee(true)->event_fee_id;
			$bookingOption->value_int = $array[$elementName][$elementIdx];
			$bookingOption->waitlist = 0;
		}
		else if ($force) {
			$bookingOption->event_fee_id = null;
			$bookingOption->value_int = 0;
		}
		else {
			if (isset($array[$elementName][$elementIdx]) && $elementName == "event_option") unset($array[$elementName][$elementIdx]);
			return null;
		}
		
		$bookingOption->changeAllowed = 0;
		
		return $bookingOption;
	}

	private function fromArrayAddInfo(EventOptionsGroup $group, EventOption $option, $array) {
		$bookingOption = new UserBookingOption();
		
		switch ($option->option_type) {
			case EVENT_OPTION_TEXT :
			case EVENT_OPTION_TEXT_MULTILINE :
			case EVENT_OPTION_SELECT :
				$bookingOption->value_str = $array["event_option"][$option->event_option_id];
				break;
			case EVENT_OPTION_DATE :
				if ($array["event_option"][$option->event_option_id])
					$bookingOption->value_date = CWFTools::dateLocal2ISO($array["event_option"][$option->event_option_id], getenv("LC_ALL"));
				else
					$bookingOption->value_date = null;
				break;
			case EVENT_OPTION_NUMBER_INT :
				if ($array["event_option"][$option->event_option_id] !== "")
					$bookingOption->value_num = $array["event_option"][$option->event_option_id];
				else
					$bookingOption->value_num = null;
				break;
			case EVENT_OPTION_NUMBER_DEC :
				if ($array["event_option"][$option->event_option_id] !== "")
					$bookingOption->value_num = CWFTools::string2Float($array["event_option"][$option->event_option_id], getenv("LC_ALL"));
				else
					$bookingOption->value_num = null;
				break;
		}
		$bookingOption->event_option_type = $option->option_type;
		$bookingOption->changeAllowed = $group->allow_changes;
		
		return $bookingOption;
	}
	
	// ///////////////////////////////////////////////////////////////////////////////////////////////
	// database operations - read
	public function readData(DbConnection $DB, $conditions = null) {
		if (is_array($conditions)) {
			$whereConditions = array();
			foreach ($conditions as $key => $value)
				if (array_key_exists($key, get_class_vars(get_class()))) $whereConditions[] = "$key=$value";
			$conditions = implode(" AND ", $whereConditions);
		}
		if (!$conditions) {
			$conditions = "user_id='{$this->user_id}' AND event_id='{$this->event_id}'";
		}
		$conditions .= " AND deleted=0";
		
		$result = $DB->query("SELECT ub.* " . "FROM user_booking ub " . "WHERE {$conditions};");
		if (!$DB->errno() && $DB->num_rows($result) > 0) {
			$booking = $DB->fetch_array($result);
			foreach ($booking as $property => $value) {
				if (property_exists($this, $property)) {
					switch ($property) {
						default :
							$this->$property = $value;
							break;
					}
				}
			}
			
			$result = $DB->query("SELECT * FROM user_booking_options WHERE deleted=0 AND booking_id='{$this->booking_id}';");
			$this->bookedOptions = array();
			while ($bookingOption = $DB->fetch_array($result)) {
				$bookedOption = new UserBookingOption();
				$bookedOption->fromArray($bookingOption);
				
				$this->bookedOptions[$bookedOption->event_option_id] = $bookedOption;
			}
			$this->bookingCheck->readData($DB, array("booking_id" => "'{$this->booking_id}'"));
		}
		
		return array($DB->errno(),$DB->error());
	}

	static public function readList(DbConnection $DB) {
		return array();
	}

	static public function getFinances($DB) {
		$sql = "SELECT sum(
              (SELECT sum(ef.event_fee*ubo.value_int)
               FROM user_booking_options ubo
                 JOIN event_fees ef ON (ef.event_fee_id=ubo.event_fee_id)
                 JOIN event_options eo ON (eo.event_option_id=ef.event_option_id)
                 JOIN event_option_groups eog ON (eog.event_option_group_id=eo.event_option_group_id)
               WHERE ubo.booking_id=ub.booking_id
                 AND ubo.deleted=0
                 AND ubo.waitlist=0
                 AND eog.group_type IN ('" . OPTION_GROUP_FEES . "', '" . OPTION_GROUP_TICKETS . "')
              ) - ifnull(ubc.discount, 0)) as fee_sum, 
              ifnull(ubc.payment_received, 0) as payment_received,
              sum(ifnull(ubc.partial_payment, 0)) as partial_payment
            FROM user_booking ub
              LEFT JOIN user_booking_check ubc ON (ubc.booking_id=ub.booking_id)
            WHERE ub.event_id='{$_SESSION['event']->event_id}'
              AND ub.deleted=0
            GROUP BY ubc.payment_received";
		$result = $DB->query($sql);
		
		$finances = array("received" => 0,"owing" => 0);
		while ($row = $DB->fetch_array($result)) {
			if ($row['partial_payment'] != 0) {
				$finances["received"] += $row['partial_payment'];
				$finances["owing"] += $row['fee_sum'] - $row['partial_payment'];
			}
			else if ($row['payment_received'])
				$finances["received"] += $row['fee_sum'];
			else
				$finances["owing"] += $row['fee_sum'];
		}
		
		return $finances;
	}
	
	// TODO
	static public function getBookingsByOption($DB) {
		$sql = "SELECT eo.event_option, 
                   sum(if(ubo.waitlist=0, ubo.value_int, 0)) as count,
                   sum(if(ubo.waitlist>0, ubo.value_int, 0)) as count_waitlisted,
                   ifnull(sum(ubc.payment_received*ubo.value_int), 0) as count_paid,
                   ifnull(sum((ubc.partial_payment>0)*ubo.value_int), 0) as count_paid_partial,
                   sum(ef.event_fee*IF(ubo.value_int, ubo.value_int, 0)) AS fee_sum,
                   eog.enable_waitlist,
                   eo.person_limit
            FROM event_option_groups eog
              JOIN event_options eo ON (eo.event_option_group_id=eog.event_option_group_id)
              JOIN event_fees ef ON (ef.event_option_id=eo.event_option_id)
              LEFT JOIN user_booking_options ubo ON (ubo.event_fee_id=ef.event_fee_id AND ubo.deleted=0)
              LEFT JOIN user_booking ub ON (ub.booking_id=ubo.booking_id AND ub.deleted=0)
              LEFT JOIN user_booking_check ubc ON (ubc.booking_id=ub.booking_id)
            WHERE eog.event_id='{$_SESSION['event']->event_id}'
              AND eog.group_type IN ('" . OPTION_GROUP_FEES . "', '" . OPTION_GROUP_TICKETS . "')
            GROUP BY eo.event_option_id
            ORDER BY eog.event_option_group_id, eo.event_option_id;";
		$result = $DB->query($sql);
		
		$bookings = array();
		while ($booking = $DB->fetch_array($result))
			$bookings[] = $booking;
		
		return $bookings;
	}
	
	// ///////////////////////////////////////////////////////////////////////////////////////////////
	// database operations - write
	public function writeData(DbConnection $DB, $force = false) {
		if (!isset($_SESSION['admin'])) $force = false;
		$isChange = false;
		if (isset($this->booking_id) && $this->booking_id) {
			$result = null;
			$isChange = true;
		}
		else if ($this->user_id && $this->event_id) {
			$result = $DB->query("INSERT INTO user_booking(
          user_id,
          event_id,
          booking_date,
          change_log,
          deleted
        ) VALUES(
          '{$this->user_id}',
          '{$this->event_id}',
          NOW(),
          null,
          0
        );");
			
			$this->booking_id = $DB->insert_id();
			$logEntry = "Booking for user {$this->user_id} and event {$this->event_id} added (id {$this->booking_id}).";
		}
		else
			return array(1,_("User id or event id not set."));
		
		if ($this->booking_id) {
			foreach ($this->bookedOptions as &$option) {
				if (!$isChange || $option->changeAllowed || $force) {
					$option->booking_id = $this->booking_id;
					list($errno, $error) = $option->writeData($DB, $force);
					if ($errno) return array($errno,$error);
				}
			}
			$logEntry = "Booking '{$this->booking_id}' changed (user {$this->user_id}, event {$this->event_id}).";
		}
		if (!$DB->errno()) {
			if (isset($_SESSION['admin'])) KDbLog::writeLog($DB, $logEntry);
			return array(0,"");
		}
		else
			return array($DB->errno(),$DB->error());
	}

	static public function updateFees(DbConnection $DB, $ids) {
		if (!is_array($ids)) return array(1,"");
		foreach ($ids as $id)
			if (!is_numeric($id)) return array(1,"");
		
		$sql = "SET @uids := null;\n" . 
			"UPDATE user_booking_options ubo\n" . 
			"SET ubo.event_fee_id=(SELECT ef2.event_fee_id ".
									"FROM event_fees ef2 ".
									"WHERE ef2.event_option_id=ubo.event_option_id ".
									  "AND ifnull(ef2.deadline, '9999-12-31')>=DATE(NOW()) ".
									  "ORDER BY ef2.deadline LIMIT 1)\n" . 
			"WHERE booking_id IN ('" . implode("', '", $ids) . "')\n" . 
			"  AND (SELECT ifnull(ef.deadline, '9999-12-31') FROM event_fees ef WHERE ef.event_fee_id=ubo.event_fee_id)<DATE(NOW())\n" . 
			"  AND (SELECT count(ef2.event_fee_id) FROM event_fees ef2 WHERE ef2.event_option_id=ubo.event_option_id AND ifnull(ef2.deadline, '9999-12-31')>=DATE(NOW()))>0\n" . 
			"  AND (SELECT @uids := CONCAT_WS(',', @uids, ubo.booking_id));\n" . "SELECT @uids;";
		
		$result = $DB->multi_query($sql);
		
		$ids = $DB->result($result, 0, 0);
		if ($ids) $DB->query("UPDATE user_booking SET change_log=concat_ws('\n', change_log, concat('Fees updated ', NOW())) WHERE booking_id IN ($ids)");
		
		return array(0,"");
	}

	static public function unDeleteData(DbConnection $DB, $id) {
		if (preg_match("~^[0-9]+$~", $id))
			$condition = "booking_id='{$id}'";
		else
			$condition = $id;
		
		$booking_ids = $DB->result($DB->query("SELECT group_concat(booking_id SEPARATOR ', ') FROM user_booking WHERE $condition;"), 0, 0);
		$DB->query("UPDATE user_booking SET deleted=0 WHERE $condition;");
		
		if (!$DB->errno() && $DB->affected_rows() > 0) {
			KDbLog::writeLog($DB, "Booking(s) restored ({$condition}).");
			UserBookingOption::unDeleteData($DB, "booking_id IN ({$booking_ids})");
			return array(0,"");
		}
		else
			return array($DB->errno(),$DB->error());
	}

	static public function deleteData(DbConnection $DB, $id, $reallyDelete = 0) {
		if (preg_match("~^[0-9]+$~", $id))
			$condition = "booking_id='{$id}'";
		else
			$condition = $id;
		
		$booking_ids = $DB->result($DB->query("SELECT group_concat(booking_id SEPARATOR ', ') FROM user_booking WHERE $condition;"), 0, 0);
		if ($reallyDelete)
			$DB->query("DELETE FROM user_booking WHERE $condition;");
		else
			$DB->query("UPDATE user_booking SET deleted=1 WHERE $condition;");
		
		if (!$DB->errno() && $DB->affected_rows() > 0) {
			KDbLog::writeLog($DB, "Booking(s) " . ($reallyDelete ? "finally " : "") . "deleted ({$condition}).");
			UserBookingOption::deleteData($DB, "booking_id IN ({$booking_ids})", $reallyDelete);
			if ($reallyDelete) UserBookingCheck::deleteData($DB, "booking_id IN ({$booking_ids})");
			return array(0,"");
		}
		else
			return array($DB->errno(),$DB->error());
	}
	
	// ///////////////////////////////////////////////////////////////////////////////////////////////
	// database operations - misc
	static public function createTable(DbConnection $DB) {
		$result = $DB->query("
      CREATE TABLE user_booking (
        booking_id int unsigned NOT NULL AUTO_INCREMENT PRIMARY KEY,
        user_id int unsigned,
        event_id int unsigned,
        booking_date datetime,
        change_log text,
        deleted tinyint,
        INDEX user_id (user_id),
        INDEX event_id (event_id)
        );");
		if ($result) {
			echo _("&nbsp;&nbsp;- creating table") . ": 'user_booking'.<br>\n";
		}
		else {
			echo _("&nbsp;&nbsp;<b>- Error when creating table</b>") . " 'user_booking'<br>\n";
			$error = 1;
		}
	}
	
	// ///////////////////////////////////////////////////////////////////////////////////////////////
	// output of formatted data
	static public function getProperties($property = null) {
		$properties = array("booked_options" => _("Booked options"), "sum" => _("Sum"));
		
		if (is_array($property)) {
			$newProperties = array();
			foreach ($property as $id => $p)
				if (isset($properties[$p])) $newProperties[$id] = $properties[$p];
			return $newProperties;
		}
		else if ($property) {
			$property = preg_replace('~^([^.]+\.)?([^.]+)$~', '\2', $property);
			return ((isset($properties[$property])) ? $properties[$property] : null);
		}
		else
			return $properties;
	}

	static public function getPropertySelect($columnNames, $addTableName = "") {
		if (is_array($columnNames)) {
			foreach ($columnNames as &$columnName)
				$columnName = self::getPropertySelect($columnName, $addTableName);
		}
		else {
			$property = preg_replace('~^([^.]+\.)?([^.]+)$~', '\2', $columnNames);
			if (!in_array($property, array("bookey_options","grandtotal"))) return $columnNames;
			
			$columnNames = $addTableName . $property;
			switch ($property) {
				case "booked_options" :
					break;
				case "grandtotal" :
					break;
			}
		}
		return $columnNames;
	}

	public function getBookedProgram($withHtml = false) {
		/*
		 * $sqlBookedProgram = "SELECT eg.group_type, eo.eo.event_option, ef.event_fee,
		 * ubo.value_int, ubo.value_str, ubo.value_num, ubo.value_date
		 * FROM event_option_groups eg
		 * JOIN event_options eo ON eo.event_option_group_id=eg.event_option_group_id
		 * JOIN event_fees ef ON ef.event_option_id=eo.event_option_id
		 * JOIN user_booking_options ubo ON ubo.event_fee_id=ef.event_fee_id
		 * WHERE ubo.booking_id='{$this->booking_id}'
		 * ORDER BY eo.event_option_id;";
		 *
		 * $result = $DB->query($sqlBookedProgram);
		 */
		mb_internal_encoding("UTF-8");
		
		$hasTickets = false;
		$lineIdx = 0;
		$lines = array();
		$chars = array("name" => 0,"count" => 0,"fee" => 0,"sum" => 0);
		$maxCount = 0;
		$waitlistCount = 0;
		$grandtotal = 0;
		foreach ($this->form->eventForm as $groupId => $group) {
			if ($group->event_group_type == OPTION_GROUP_TICKETS) $hasTickets = true;
			$lines[$lineIdx]['newGroup'] = 1;
			$lines[$lineIdx]['count'] = "";
			$lines[$lineIdx]['name'] = $group->group_name;
			if (!$group->exclusive) $lineIdx++;
			foreach ($group->eventOptions as $optionId => $option) {
				if (isset($this->bookedOptions[$option->event_option_id]) && $this->bookedOptions[$option->event_option_id]->getValue()) {
					$lines[$lineIdx]['name'] = (isset($lines[$lineIdx]['name']) ? "{$lines[$lineIdx]['name']}: " : "  ") . $option->event_option;
					$lines[$lineIdx]['count'] = "";
					
					if (in_array($group->group_type, array(OPTION_GROUP_FEES,OPTION_GROUP_TICKETS))) {
						$count = $this->bookedOptions[$option->event_option_id]->value_int;
						$lines[$lineIdx]['count'] = $count;
						$maxCount = max(array($maxCount,$lines[$lineIdx]['count']));
						
						if ($option->eventFees[$this->bookedOptions[$option->event_option_id]->event_fee_id]->event_fee != null) {
							$fee = $option->eventFees[$this->bookedOptions[$option->event_option_id]->event_fee_id]->event_fee;
							$lines[$lineIdx]['fee'] = $fee . " " . KDbConfig::getCurrency();
							$lines[$lineIdx]['sum'] = $lines[$lineIdx]['count'] * $fee . " " . KDbConfig::getCurrency();
							$lines[$lineIdx]['waitlist'] = $this->bookedOptions[$option->event_option_id]->waitlist;
							$waitlistCount += $this->bookedOptions[$option->event_option_id]->waitlist;
							$grandtotal += $count * $fee;
						}
						else {
							$lines[$lineIdx]['fee'] = "";
							$lines[$lineIdx]['sum'] = "";
							$lines[$lineIdx]['waitlist'] = "";
						}
						$chars = $this->getMaxLength($chars, $lines[$lineIdx]['count'], KDbTools::getHTMLDecodedStr($lines[$lineIdx]['name']), $lines[$lineIdx]['fee'], $lines[$lineIdx]['sum']);
					}
					else {
						$chars = $this->getMaxLength($chars, 0, KDbTools::getHTMLDecodedStr($lines[$lineIdx]['name']), 0, 0);
						$lines[$lineIdx]['text'] = $this->bookedOptions[$option->event_option_id]->getValue(true);
					}
					
					$lineIdx++;
				}
			}
		}
		
		$feeCol = ($maxCount > 1 ? "sum" : "fee");
		if ($this->bookingCheck->discount) {
			$lines[$lineIdx] = array('isTotal'=>1, 'count' => "", 'name' => _("Subtotal"), 'fee' => "",'sum' => "");
			$lines[$lineIdx][$feeCol] = $grandtotal . " " . KDbConfig::getCurrency();
			$chars = $this->getMaxLength($chars, "", $lines[$lineIdx]['name'], $lines[$lineIdx]['fee'], $lines[$lineIdx]['sum']);
			$lineIdx++;
			$lines[$lineIdx] = array('count' => "",'name' => _("Discount"),'fee' => "",'sum' => "");
			$lines[$lineIdx][$feeCol] = $this->bookingCheck->discount . " " . KDbConfig::getCurrency();
			$chars = $this->getMaxLength($chars, "", $lines[$lineIdx]['name'], $lines[$lineIdx]['fee'], $lines[$lineIdx]['sum']);
			$grandtotal -= $this->bookingCheck->discount;
			$lineIdx++;
			$lines[$lineIdx] = array('isTotal'=>1, 'count' => "", 'name' => _("TOTAL"), 'fee' => "",'sum' => "");
			$lines[$lineIdx][$feeCol] = $grandtotal . " " . KDbConfig::getCurrency();
			$chars = $this->getMaxLength($chars, "", $lines[$lineIdx]['name'], $lines[$lineIdx]['fee'], $lines[$lineIdx]['sum']);
			$lineIdx++;
		}
		else {
			$lines[$lineIdx] = array('isTotal'=>1, 'count' => "", 'name' => _("TOTAL"), 'fee' => "",'sum' => "");
			$lines[$lineIdx][$feeCol] = $grandtotal . " " . KDbConfig::getCurrency();
			$chars = $this->getMaxLength($chars, "", $lines[$lineIdx]['name'], $lines[$lineIdx]['fee'], $lines[$lineIdx]['sum']);
			$lineIdx++;
		}
		if($this->bookingCheck->partial_payment) {
			$lines[$lineIdx] = array('count' => "",'name' => _("Partial payment received"),'fee' => "",'sum' => "");
			$lines[$lineIdx][$feeCol] = $this->bookingCheck->partial_payment . " " . KDbConfig::getCurrency();
			$chars = $this->getMaxLength($chars, "", $lines[$lineIdx]['name'], $lines[$lineIdx]['fee'], $lines[$lineIdx]['sum']);
			$grandtotal -= $this->bookingCheck->partial_payment;
			$lineIdx++;
			$lines[$lineIdx] = array('isTotal'=>1, 'count' => "", 'name' => _("TOTAL owing"), 'fee' => "",'sum' => "");
			$lines[$lineIdx][$feeCol] = $grandtotal . " " . KDbConfig::getCurrency();
			$chars = $this->getMaxLength($chars, "", $lines[$lineIdx]['name'], $lines[$lineIdx]['fee'], $lines[$lineIdx]['sum']);
			$lineIdx++;
		}
		if($this->bookingCheck->payment_received) {
			$lines[$lineIdx] = array('count' => "", 'name' => _("payment received"), 'fee' => "",'sum' => "");
			$chars = $this->getMaxLength($chars, "", $lines[$lineIdx]['name'], $lines[$lineIdx]['fee'], $lines[$lineIdx]['sum']);
			$lineIdx++;
		}
		
		if ($withHtml) {
			$str = "<table class=\"padding\" style=\"border-collapse: collapse;\">\n";
			$str .= "<colgroup>\n";
			$str .= "  <col style=\"min-width:250px;\"><col>\n";
			$str .= "<colgroup>\n";
			$groupCount = count($this->form->eventForm);
			foreach ($lines as $lineIdx => $line) {
				$str .= "<tr" . (isset($line['waitlist']) && $line['waitlist'] ? " class=\"waitlisted\"" : "") . ">\n";
				$addStyle = "";
				if(isset($line['isTotal'])) $addStyle = "border-top:3px double black; ";
				else if ($groupCount > 1 && isset($line['newGroup']) && $lineIdx > 0) $addStyle = "border-top:1px solid black; ";
				if ($maxCount > 1) {
					$str .= "  <td style=\"{$addStyle}text-align:right;\">" . $line['count'] . "</td>\n";
				}
				$str .= "  <td style=\"{$addStyle}\">" . $line['name'] . "</td>\n";
				if (isset($line['fee'])) {
					$str .= "  <td style=\"{$addStyle}text-align:right;\">" . $line['fee'] . "</td>\n";
					$str .= "  <td style=\"{$addStyle}text-align:right;\">" . ($maxCount > 1 ? $line['sum'] : "") . "</td>\n";
					$str .= "  <td style=\"{$addStyle}\">" . ((isset($line['waitlist']) && $line['waitlist']) ? "(" . _("waitlisted") . ")" : "") . "</td>\n";
				}
				else if (isset($line['text']))
					$str .= "  <td colspan=\"3\" style=\"{$addStyle}\">" . $line['text'] . "</td>\n";
				else
					$str .= "  <td colspan=\"3\" style=\"{$addStyle}\"></td>\n";
				$str .= "</tr>\n";
			}
			$str .= "</table>\n";
		}
		else {
			$str = "";
			foreach ($lines as $line) {
				if(isset($line['isTotal']))
					$str .= "  " . str_repeat("-", ($maxCount > 1 ? $chars['count'] + 2 : 0) + $chars['name'] + (isset($line['fee']) ? $chars['fee'] + 2 + ($maxCount > 1 ? $chars['sum'] + 2 : 0) : 0)) . "\n";
				if ($maxCount > 1) $str .= "  " . CWFTools::mb_strpad($line['count'], $chars['count'], " ", STR_PAD_LEFT);
				$str .= "  " . CWFTools::mb_strpad(KDbTools::getHTMLDecodedStr($line['name']), $chars['name'], " ", STR_PAD_RIGHT);
				if (isset($line['fee'])) {
					$str .= "  " . CWFTools::mb_strpad($line['fee'], $chars['fee'], " ", STR_PAD_LEFT);
					if ($maxCount > 1) 
						$str .= "  " . CWFTools::mb_strpad($line['sum'], $chars['sum'], " ", STR_PAD_LEFT);
					if (isset($line['waitlist']) && $line['waitlist']) 
						$str .= " (" . _("waitlisted") . ")";
				}
				else if (isset($line['text'])) 
					$str .= "  " . $line['text'];
				$str .= "\n";
			}
		}
		
		return $str;
	}

	private function getMaxLength($chars, $count, $name, $fee, $sum) {
		$chars['count'] = max(array($chars['count'], mb_strlen($count)));
		$chars['name'] = max(array($chars['name'], mb_strlen($name)));
		$chars['sum'] = max(array($chars['sum'], mb_strlen($sum)));
		$chars['fee'] = max(array($chars['fee'], mb_strlen($fee)));
		
		return $chars;
	}

	public function getGrandTotal(DbConnection $DB) {
		$sqlGrandTotal = "SELECT sum(ef.event_fee*ubo.value_int)-ifnull((SELECT discount FROM user_booking_check ubc WHERE ubc.booking_id=ubo.booking_id), 0)
    FROM event_fees ef
      JOIN user_booking_options ubo ON ubo.event_fee_id=ef.event_fee_id
    WHERE ubo.booking_id='{$this->booking_id}';";
		return $DB->result($DB->query($sqlGrandTotal), 0, 0);
	}

	public function getFormData() {
		$formData = array();
		$formAddInfo = "";
		foreach ($this->form->eventForm as $groupId => $group) {
			foreach ($group->eventOptions as $optionId => $option) {
				if (isset($this->bookedOptions[$option->event_option_id]) && $this->bookedOptions[$option->event_option_id]->getValue()) {
					switch ($group->group_type) {
						case OPTION_GROUP_FEES :
							$formData[] = $option->event_option;
							break;
						case OPTION_GROUP_TICKETS :
							$formData[] = $option->event_option . " ({$this->bookedOptions[$option->event_option_id]->getValue()})";
							break;
						case OPTION_GROUP_ADDINFO :
							$formAddInfo .= $option->event_option . ": " . $this->bookedOptions[$option->event_option_id]->getValue(true) . "\n";
							break;
					}
				}
			}
		}
		$formDataText = _("Booked program") . ": " . implode(", ", $formData) . ($formAddInfo ? "\n" . $formAddInfo : "");
		
		return $formDataText;
	}

	public function getConfirmationText(DbConnection $DB, $confirmationText, $withHtml = false) {
		$confirmationText = str_replace("\$booked_program\$", $this->getBookedProgram($withHtml), $confirmationText);
		$confirmationText = str_replace("\$grandtotal\$", $this->getGrandTotal($DB), $confirmationText);
		
		return $confirmationText;
	}
}
?>
