<?php
require_once ("cwfUI.inc.php");
class UserBookingUI extends cwfUI {
	public $data;
	protected $error;
	protected $containsAddInfo;
	
	// ///////////////////////////////////////////////////////////////////////////////////////////////
	// initialize
	public function __construct(DbConnection $DB, $eventId = null) {
		parent::__construct();
		$this->error = "";
		$this->containsAddInfo = 0;
		
		if (!$eventId && !isset($_SESSION['event']))
			$this->error = _("No event selected.");
		else {
			$this->data = new UserBooking();
			if ($eventId)
				$this->data->setEventId($DB, $eventId);
			else
				$this->data->setEventId($DB, $_SESSION['event']->event_id);
			
			if (isset($_SESSION['user']) && !$_SESSION['event']->allow_multiple_reg) {
				$this->data->readData($DB);
				if ($this->data->booking_id) $_SESSION['booking_id'] = $this->data->booking_id;
			}
			else if (isset($_SESSION['registration']['booking_id']) && $_SESSION['registration']['booking_id'] && 
					$_SESSION['registration']['event_id']==$_SESSION['event']->event_id) {
				$this->data->readData($DB, "booking_id='{$_SESSION['registration']['booking_id']}'");
			}
			
			$this->data->setValidation(self::getValidationRules($this->data->form, (bool)$this->data->booking_id));
		}
		
		$this->title = _("Registration");
		$this->header = "  <script type=\"text/javascript\">
    $(document).ready(function() {
      $(\"form\").validate({
        errorClass: 'invalid',\n" . $this->data->validation->getValidationRulesJQuery("        ") . "
      });
    });
  </script>\n";
		if ((isset($_POST['kdb_save']) && $_POST['kdb_save'])) {
			if (!isset($_SESSION['registration']['booking_id'])) {
				if (isset($_SESSION['user'])) {
					if ($this->saveForm($DB) && !isset($_SESSION['booking_id'])) $_SESSION['registration']['booking_id'] = $this->data->booking_id;
				}
				else
					$this->data->fromArray($_POST);
			}
		}
		else if (isset($_SESSION['registration']['booking_id']) && isset($_POST['reg_finish']) && $_POST['reg_finish']) {
			unset($_SESSION['registration']['booking_id']);
			unset($_SESSION['registration']['event_id']);
			if ($_SESSION['event']->allow_multiple_reg) {
				$this->data = new UserBooking();
				if ($eventId)
					$this->data->setEventId($DB, $eventId);
				else
					$this->data->setEventId($DB, $_SESSION['event']->event_id);
			}
		}
	}
	
	// ///////////////////////////////////////////////////////////////////////////////////////////////
	// handle data
	public function getErrorMessage() {
		return $this->error;
	}

	static public function getValidationRules(EventForm $form = null, $isChange = false) {
		global $DB;
		
		if (!$form) {
			$form = new EventForm();
			if (isset($_SESSION['event'])) {
				$form->setEventId($_SESSION['event']->event_id);
				$form->readData($DB);
			}
		}
		
		$rules = array();
		$messages = array();
		foreach ($form->eventForm as $groupId => $group) {
			foreach ($group->eventOptions as $optionId => $option) {
				if (!$isChange || $group->allow_changes) {
					switch ($group->group_type) {
						case OPTION_GROUP_FEES :
							if ($group->required) {
								if ($group->exclusive) {
									$rules["event_option_g[{$groupId}]"] = array(
										"required" => true 
									);
									$messages["event_option_g[{$groupId}]"] = array(
										"required" => _("Please select at least one of the options below.") 
									);
								}
								else {
									$rules["event_option[{$option->event_option_id}]"] = array(
										"required" => true 
									);
									$messages["event_option[{$option->event_option_id}]"] = array(
										"required" => _("Please select this option.") 
									);
								}
							}
							break;
						case OPTION_GROUP_TICKETS :
							if ($group->required) {
								$rules["event_option_g[{$groupId}]"] = array(
									"required" => true 
								);
								if ($group->exclusive) {
									$rules["no_tickets[{$groupId}]"] = array(
										"required" => true 
									);
									$messages["event_option_g[{$groupId}]"] = array(
										"required" => _("Please choose a category and the number of tickets.") 
									);
									$messages["no_tickets[{$groupId}]"] = array(
										"required" => _("Please choose the number of tickets.") 
									);
								}
								else
									$messages["event_option_g[{$groupId}]"] = array(
										"required" => _("Please choose number of tickets for at least one category below.") 
									);
							}
							break;
						case OPTION_GROUP_ADDINFO :
							switch ($option->option_type) {
								case EVENT_OPTION_TEXT :
								case EVENT_OPTION_TEXT_MULTILINE :
								case EVENT_OPTION_SELECT :
									if ($group->required) {
										$rules["event_option[{$option->event_option_id}]"] = array(
											"required" => true 
										);
										$messages["event_option[{$option->event_option_id}]"] = array(
											"required" => _("This field is mandatory.") 
										);
									}
									break;
								case EVENT_OPTION_DATE :
									if ($group->required) {
										$rules["event_option[{$option->event_option_id}]"] = array(
											"required" => true,
											"date_" . getenv("LC_ALL") => true 
										);
										$messages["event_option[{$option->event_option_id}]"] = array(
											"required" => _("This field is mandatory."),
											"date_" . getenv("LC_ALL") => _("Please enter a valid date, e.g. ") . CWFTools::dateISO2Local("2000-12-31", getenv("LC_ALL")) 
										);
									}
									else {
										$rules["event_option[{$option->event_option_id}]"] = array(
											"date_" . getenv("LC_ALL") => true 
										);
										$messages["event_option[{$option->event_option_id}]"] = array(
											"date_" . getenv("LC_ALL") => _("Please enter a valid date, e.g. ") . CWFTools::dateISO2Local("2000-12-31", getenv("LC_ALL")) 
										);
									}
									break;
								case EVENT_OPTION_NUMBER_INT :
									if ($group->required) {
										$rules["event_option[{$option->event_option_id}]"] = array(
											"required" => true,
											"digits" => true 
										);
										$messages["event_option[{$option->event_option_id}]"] = array(
											"required" => _("This field is mandatory."),
											"digits" => _("Please enter a whole number, e.g. 12") 
										);
									}
									else {
										$rules["event_option[{$option->event_option_id}]"] = array(
											"digits" => true 
										);
										$messages["event_option[{$option->event_option_id}]"] = array(
											"digits" => _("Please enter a whole number, e.g. 12") 
										);
									}
									break;
								case EVENT_OPTION_NUMBER_DEC :
									if ($group->required) {
										$rules["event_option[{$option->event_option_id}]"] = array(
											"required" => true,
											"number_int" => true 
										);
										$messages["event_option[{$option->event_option_id}]"] = array(
											"required" => _("This field is mandatory."),
											"number" => _("Please enter a (decimal) number, e.g. 12.3") 
										);
									}
									else {
										$rules["event_option[{$option->event_option_id}]"] = array(
											"number_int" => true 
										);
										$messages["event_option[{$option->event_option_id}]"] = array(
											"number_int" => _("Please enter a (decimal) number, e.g. 12.3") 
										);
									}
									break;
							}
							break;
					}
				}
			}
		}
		
		$validationRules = new FormValidation($rules, $messages);
		return $validationRules;
	}

	public function addValidationRules(FormValidation $validationRules) {
		$this->data->validation->addRules($validationRules);
		
		$this->header = "  <script type=\"text/javascript\">
    $(document).ready(function(){
      $(\"form\").validate({
        errorClass: 'invalid',\n" . $this->data->validation->getValidationRulesJQuery("        ") . "
      });
    });
  </script>\n";
	}
	
	// ///////////////////////////////////////////////////////////////////////////////////////////////
	// Database operations
	public function saveForm(DbConnection $DB) {
		if ($this->data->fromArray($_POST) && $this->data->user_id) {
			list($errno, $error) = $this->data->writeData($DB);
			if ($errno) {
				$this->error = $error;
				return 0;
			}
			else
				return 1;
		}
		return 0;
	}
	
	// ///////////////////////////////////////////////////////////////////////////////////////////////
	// output
	public function printSubmitButtons() {
		return $this->containsAddInfo;
	}

	public function getHTMLView(DbConnection $DB, $allFields = true, $noFormControls = 0) {
		if ($noFormControls) {
			$this->getHTMLRegistration($DB, $allFields);
		}
		else {
			echo "<form id=\"kdb_form_booking\" action=\"\" method=\"post\" enctype=\"multipart/form-data\">\n";
			echo "<h2 class=\"first\">" . _("Register for") . ": {$_SESSION['event']->event_title}</h2>\n\n";
			echo "<input type=\"hidden\" name=\"user_id\" id=\"user_id\" value=\"{$this->data->user_id}\">\n\n";
			echo "<input type=\"hidden\" name=\"booking_id\" id=\"booking_id\" value=\"{$this->data->booking_id}\">\n\n";
			$this->getHTMLRegistration($DB, $allFields);
			?>
<div class="form_controls_bottom">
	<p>
		<input type="submit" id="kdb_save2" name="kdb_save"
			value="<?=_("Save")?>"
			onClick="kdbSaveEntry('ViewDataUI', 'save', 'kdb_form_booking', refreshHiddenColumns);  return false;">
		<input type="submit" id="kdb_save_close2" name="kdb_save_close"
			value="<?=_("Save and close")?>"
			onClick="kdbSaveEntry('ViewDataUI', 'save', 'kdb_form_booking', refreshHiddenColumns); $('#dialog_view').hide(); return false;">
	</p>
</div>
<?php
			echo "</form>\n";
		}
	}

	public function getHTML(DbConnection $DB) {
		if ($this->data->booking_id) {
			echo "<input type=\"hidden\" name=\"booking_id\" id=\"booking_id\" value=\"{$this->data->booking_id}\">\n\n";
			echo "<h3>" . _("Event fees") . "</h3>\n";
			echo "<table class=\"padding alignleft borderrowsselect\">\n";
			echo "<colgroup>\n";
			echo "  <col style=\"min-width:250px;\"><col>\n";
			echo "<colgroup>\n";
			$grandtotal = 0;
			$waitlistCount = 0;
			$first = 1;
			foreach ($this->data->form->eventForm as $groupId => $group) {
				if (in_array($group->group_type, array(OPTION_GROUP_FEES, OPTION_GROUP_TICKETS))) {
					echo "<tr class=\"withborder\">\n";
					if ($first) {
						echo "  <th colspan=\"2\"><h4 class=\"first\">{$group->group_name}</h4>";
						$first = 0;
					}
					else
						echo "  <th colspan=\"2\"><h4>{$group->group_name}</h4>";
					echo "</th>\n</tr>\n";
					$bookedOptionsCount = 0;
					foreach ($group->eventOptions as $optionId => $option) {
						if (isset($this->data->bookedOptions[$option->event_option_id])) {
							$bookedOptionsCount++;
							$waitlistCount += $this->data->bookedOptions[$option->event_option_id]->waitlist;
							$feeIdx = $this->data->bookedOptions[$option->event_option_id]->event_fee_id;
							$fee = $option->eventFees[$feeIdx]->event_fee * $this->data->bookedOptions[$option->event_option_id]->value_int;
							$grandtotal += $fee;
							echo "<tr" . ($this->data->bookedOptions[$option->event_option_id]->waitlist ? " class=\"waitlisted\"" : "") . ">\n";
							
							$feeText = ($option->eventFees[$feeIdx]->event_fee != "" && $option->eventFees[$feeIdx]->event_fee != null ? KDbConfig::getCurrency() . " {$fee}" : "");
							switch ($group->group_type) {
								case OPTION_GROUP_FEES :
									echo "  <td>{$option->event_option}</td>\n";
									echo "  <td class=\"alignright\">" . $feeText . ($this->data->bookedOptions[$option->event_option_id]->waitlist ? "*" : "") . "</td>\n";
									break;
								
								case OPTION_GROUP_TICKETS :
									echo "  <td>{$option->event_option} " . ($feeText != "" ? "(" . KDbConfig::getCurrency() . " {$option->eventFees[$feeIdx]->event_fee})" : "") . "</td>\n";
									echo "  <td class=\"alignright\">" . $feeText . ($this->data->bookedOptions[$option->event_option_id]->waitlist ? "*" : "") . "</td>\n";
									break;
							}
							echo "</tr>\n";
						}
					}
					if ($bookedOptionsCount == 0) {
						echo "<tr>\n";
						echo "  <td colspan=\"2\">" . _("Nothing has been booked in this category") . "</td>\n";
						echo "</tr>\n";
					}
				}
			}
			$payment_received_text = "";
			if ($this->data->bookingCheck->payment_received && !$this->data->bookingCheck->discount)
				$payment_received_text = "<br> (" . _("payment received") . ")";
			echo "<tr class=\"spacer\"></tr>\n";
			echo "<tr class=\"grandtotal withbordertop\">\n";
			echo "  <td>" . ($this->data->bookingCheck->discount ? _("Subtotal") : _("TOTAL")) . "</td>\n";
			echo "  <td class=\"alignright\">" . KDbConfig::getCurrency() . " {$grandtotal}" . $payment_received_text . "</td>\n";
			echo "</tr>\n";
			if ($this->data->bookingCheck->discount) {
				echo "<tr class=\"discount\">\n";
				echo "  <td>" . _("Discount") . "</td>\n";
				echo "  <td class=\"alignright\">" . KDbConfig::getCurrency() . " {$this->data->bookingCheck->discount}</td>\n";
				echo "</tr>\n";
				$grandtotal -= $this->data->bookingCheck->discount;
				if ($this->data->bookingCheck->payment_received)
					$payment_received_text = "<br> (" . _("payment received") . ")";
				echo "<tr class=\"grandtotal withbordertop\">\n";
				echo "  <td>" . _("TOTAL") . "</td>\n";
				echo "  <td class=\"alignright\">" . KDbConfig::getCurrency() . " {$grandtotal}" . $payment_received_text . "</td>\n";
				echo "</tr>\n";
			}
			if ($this->data->bookingCheck->partial_payment) {
				echo "<tr>\n";
				echo "  <td>" . _("Partial payment received") . "</td>\n";
				echo "  <td class=\"alignright\">" . KDbConfig::getCurrency() . " {$this->data->bookingCheck->partial_payment}</td>\n";
				echo "</tr>\n";
				$grandtotal -= $this->data->bookingCheck->partial_payment;
				echo "<tr class=\"grandtotal withborder\">\n";
				echo "  <td>" . _("TOTAL owing") . "</td>\n";
				echo "  <td class=\"alignright\">" . KDbConfig::getCurrency() . " ".$grandtotal."</td>\n";
				echo "</tr>\n";
			}
			echo "</table>\n\n";
			if ($waitlistCount > 0) echo "<p class=\"waitlisted\">* " . _("waitlisted") . "</p>\n";
			foreach ($this->data->form->eventForm as $groupId => $group) {
				if ($group->group_type == OPTION_GROUP_ADDINFO) {
					$readonly = "";
					if (!$group->allow_changes)
						$readonly = " readonly";
					else
						$this->containsAddInfo = 1;
					echo "<h3>{$group->group_name}</h3>\n";
					
					foreach ($group->eventOptions as $optionId => $option) {
						echo "<p>\n";
						$this->printAddInfo($group, $option, $readonly);
						echo "</p>\n";
					}
				}
			}
		}
		else {
			$this->getHTMLRegistration($DB);
		}
	}

	public function getHTMLRegistration(DbConnection $DB, $allFields = false) {
		if (!isset($_SESSION['admin'])) $allFields = false;
		
		foreach ($this->data->form->eventForm as $groupId => $group) {
			echo "<h3>{$group->group_name}";
			if ($group->required && (($group->group_type == OPTION_GROUP_FEES && $group->exclusive) || ($group->group_type == OPTION_GROUP_TICKETS && !$group->exclusive))) {
				if (!$this->data->validation->isValid("event_option_g[{$groupId}]"))
					echo "  <label class=\"invalid\" for=\"event_option_g[$groupId]\" generated=\"true\">" . $this->data->validation->getInvalidMessage("event_option_g[{$groupId}]") . "</label>";
				else
					echo "  <label class=\"invalid\" for=\"event_option_g[$groupId]\" generated=\"true\" style=\"display:none;\"></label>";
			}
			if ($group->group_type == OPTION_GROUP_TICKETS && !$group->exclusive) {
				echo "  <input type=\"hidden\" value=\"\" name=\"event_option_g[{$group->event_option_group_id}]\" id=\"event_option_g[{$group->event_option_group_id}]\">";
			}
			if ($group->group_type == OPTION_GROUP_FEES && $group->exclusive && $allFields) {
				echo "  <input type=\"button\" id=\"remove_selection\" value=\"" . _("Remove selection") . "\" onClick=\"$('input[name=\\'event_option_g[{$group->event_option_group_id}]\\']:checked').prop('checked', false);\">";
			}
			echo "</h3>\n";
			if ($group->description) {
				echo "<p>" . CWFTools::removeSuspiciousHTML(CWFTools::getHTMLDecodedStr($group->description)) . "</p>\n";
			}
			if ($group->group_type == OPTION_GROUP_TICKETS && $group->exclusive) {
				echo "<p>\n";
				$this->printTicketsExclusive($group, $allFields);
				if (!$this->data->validation->isValid("event_option_g[{$groupId}]"))
					echo "  <label class=\"invalid\" for=\"event_option_g[$groupId]\" generated=\"true\">" . $this->data->validation->getInvalidMessage("event_option_g[{$groupId}]") . "</label>";
				else
					echo "  <label class=\"invalid\" for=\"event_option_g[$groupId]\" generated=\"true\" style=\"display:none;\"></label>";
				echo "</p>\n";
			}
			else {
				foreach ($group->eventOptions as $optionId => $option) {
					echo "<p>\n";
					switch ($group->group_type) {
						case OPTION_GROUP_FEES :
							$this->printEventFees($group, $option, $allFields);
							break;
						case OPTION_GROUP_TICKETS :
							$this->printTickets($group, $option, $allFields);
							break;
						case OPTION_GROUP_ADDINFO :
							$this->printAddInfo($group, $option);
							break;
					}
					if ($group->group_type != OPTION_GROUP_TICKETS && !$group->exclusive) {
						if (!$this->data->validation->isValid("event_option_g[{$groupId}]"))
							echo "  <label class=\"invalid\" for=\"event_option[{$option->event_option_id}]\" generated=\"true\">" . $this->data->validation->getInvalidMessage("event_option_g[{$groupId}]") . "</label>";
						else
							echo "  <label class=\"invalid\" for=\"event_option[{$option->event_option_id}]\" generated=\"true\" style=\"display:none;\"></label>";
					}
					echo "</p>\n";
				}
			}
		}
	}

	private function getClassString($classArray) {
		if (count($classArray) > 0)
			return "class=\"" . implode(" ", $classArray) . "\" ";
		else
			return "";
	}

	private function printEventFees(EventOptionsGroup $group, EventOption $option, $allFields) {
		$elementId = "event_option[{$option->event_option_id}]";
		$class = ($group->required ? " class=\"required\"" : "");
		if ($group->exclusive)
			$elementName = "event_option_g[{$group->event_option_group_id}]";
		else
			$elementName = "event_option[{$option->event_option_id}]";
		echo "  <label for=\"$elementId\"$class>{$option->event_option}</label>\n";
		// ///////////////////////////////////////////////////////////////////////////////
		// form for administration
		if ($allFields) {
			$type = (($group->exclusive) ? "radio" : "checkbox");
			$firstElement = 1;
			foreach ($option->eventFees as $feeCount => $fee) {
				$checked = ((isset($this->data->bookedOptions[$option->event_option_id]) && $this->data->bookedOptions[$option->event_option_id]->getValue() == $fee->event_fee_id) ? " checked" : "");
				if (!$firstElement) {
					echo "  <span class=\"indented\">&nbsp;<input type=\"{$type}\" name=\"{$elementName}\" id=\"{$elementId}\" value=\"{$fee->event_fee_id}\"{$checked}></span>\n";
				}
				else {
					$firstElement = 0;
					echo "  <input type=\"{$type}\" name=\"{$elementName}\" id=\"{$elementId}\" value=\"{$fee->event_fee_id}\"{$checked}>\n";
				}
				if ($fee->event_fee != "" && $fee->event_fee != null)
					echo "  <label for=\"{$elementId}\" class=\"fee\">" . KDbConfig::getCurrency() . "&nbsp;{$fee->event_fee}" . ($fee->deadline ? " (" . CWFTools::dateISO2Local($fee->deadline, getenv("LC_ALL")) . ")" : "") . "</label><br>\n";
				else
					echo "  <br>\n";
			}
			if ($_SESSION['event']->event_id == $this->data->form->event_id && $group->enable_waitlist) {
				echo "  <span class=\"indented\">&nbsp;<input type=\"checkbox\" name=\"waitlist_{$elementName}\" id=\"waitlist_{$elementId}\" value=\"1\"" . ((isset($this->data->bookedOptions[$option->event_option_id]) && $this->data->bookedOptions[$option->event_option_id]->waitlist) ? " checked" : " checked") . "></span>\n";
				echo "  <label for=\"waitlist_{$elementId}\" class=\"fee\">" . _("waitlist booking") . "</label>\n";
			}
		}
		// ///////////////////////////////////////////////////////////////////////////////
		// form for users
		else {
			$fee = $option->getCurrentFee();
			$optionStatus = _('booking deadline exceeded (deadline: ') . CWFTools::dateISO2Local($option->getLastDeadline(), getenv("LC_ALL")) . ")";
			
			if ($fee == null) {
				echo "  <input type=\"" . (($group->exclusive) ? "radio" : "checkbox") . "\" name=\"{$elementName}\" id=\"{$elementId}\" value=\"\" disabled>\n";
				echo "  <label for=\"{$elementId}\" class=\"fee\">" . $optionStatus . "</label>\n";
			}
			else {
				$optionStatus = "";
				if ($option->person_limit > 0 && $option->person_limit <= $option->no_of_bookings) $optionStatus = _('booked out');
				
				$type = (($group->exclusive) ? "radio" : "checkbox");
				$checked = ((isset($this->data->bookedOptions[$option->event_option_id]) && $this->data->bookedOptions[$option->event_option_id]->getValue() == $fee->event_fee_id) ? " checked" : "");
				if ($optionStatus)
					echo "  <input type=\"{$type}\" name=\"{$elementName}\" id=\"{$elementId}\" value=\"\" disabled>\n";
				else
					echo "  <input type=\"{$type}\" name=\"{$elementName}\" id=\"{$elementId}\" value=\"{$fee->event_fee_id}\"{$checked}>\n";
				echo "  <label for=\"{$elementId}\" class=\"fee\">";
				if ($fee->event_fee != "" && $fee->event_fee != null) echo KDbConfig::getCurrency() . "&nbsp;{$fee->event_fee}";
				if ($optionStatus) echo " ({$optionStatus})";
				echo "</label>\n";
				if ($optionStatus && $group->enable_waitlist) {
					echo "<br>\n";
					echo "  <span class=\"indented\">&nbsp;<input type=\"{$type}\" name=\"{$elementName}\" id=\"{$elementId}\" value=\"{$fee->event_fee_id}\"{$checked}></span>\n";
					echo "  <label for=\"{$elementId}\" class=\"fee\">" . _("waiting list") . "</label>\n";
				}
			}
		}
	}

	private function printTickets(EventOptionsGroup $group, EventOption $option, $allFields) {
		echo "  <label for=\"event_option[{$option->event_option_id}]\">{$option->event_option}</label>\n";
		$fee = $option->getCurrentFee(true);
		if ($fee) echo "<span class=\"form_element\">" . KDbConfig::getCurrency() . " {$fee->event_fee}.-- </span>";
		$disabled = "";
		if ($option->person_limit > 0 && $option->person_limit <= $option->no_of_bookings && !$allFields) $disabled = " disabled";
		echo "    <select class=\"no_tickets eog_{$group->event_option_group_id}\" " . "name=\"event_option[{$option->event_option_id}]\" id=\"event_option[{$option->event_option_id}]\"{$disabled} " . "onchange=\"$('#event_option_g\\\\[{$group->event_option_group_id}\\\\]').val(($('.eog_{$group->event_option_group_id} option[value!=]:selected').length>0 ? '1' : ''));\">\n";
		echo "      <option value=\"\"></option>\n";
		for ($i = 1; $i <= $option->booking_limit; $i++) {
			$checked = (isset($this->data->bookedOptions[$option->event_option_id]) && $this->data->bookedOptions[$option->event_option_id]->getValue() == $i ? " checked" : "");
			$disabled = "";
			if ($option->person_limit > 0 && $option->person_limit < $option->no_of_bookings + $i && !$allFields) $disabled = " disabled";
			echo "      <option value=\"{$i}\"{$checked}{$disabled}>{$i} " . ($i > 1 ? _("tickets") : _("ticket")) . "</option>\n";
		}
		echo "    </select>\n";
	}

	private function printTicketsExclusive(EventOptionsGroup $group, $allFields) {
		$options = "";
		$maxTickets = array();
		$bookedOption = null;
		foreach ($group->eventOptions as $optionId => $option) {
			$disabled = "";
			if ($option->person_limit > 0 && $option->person_limit <= $option->no_of_bookings && !$allFields) $disabled = " disabled";
			$checked = "";
			if (!$bookedOption && isset($this->data->bookedOptions[$option->event_option_id]) && $this->data->bookedOptions[$option->event_option_id]->getValue() > 0) {
				$checked = " checked";
				$bookedOption = $option->event_option_id;
			}
			$fee = $option->getCurrentFee(true);
			$options .= "    <option value=\"{$optionId}\"{$checked}{$disabled}>{$option->event_option}" . ($fee ? " (" . KDbConfig::getCurrency() . " {$fee->event_fee}.--)" : "") . "</option>\n";
			$ticketsLeft = ($allFields ? $option->booking_limit : min(array(
				$option->booking_limit,
				$option->person_limit - $option->no_of_bookings 
			)));
			$maxTickets[] = "'{$option->event_option_id}': { 'max' : {$option->booking_limit}, 'currentMax' : {$ticketsLeft} }";
		}
		echo "  <select class=\"ticket_category\" name=\"event_option_g[{$group->event_option_group_id}]\" id=\"event_option_g[{$group->event_option_group_id}]\" onchange=\"changeTicketCategory($(this), {" . implode(", ", $maxTickets) . "}, {false:'" . _("ticket") . "', true:'" . _("tickets") . "'});\">\n";
		echo "    <option value=\"\">" . _("Choose category") . "</option>\n";
		echo $options;
		echo "  </select>\n";
		echo "  <select class=\"no_tickets\" name=\"no_tickets[{$group->event_option_group_id}]\" id=\"no_tickets[{$group->event_option_group_id}]\"" . (!$bookedOption ? " disabled" : "") . ">\n";
		echo "    <option value=\"\"></option>\n";
		if ($bookedOption) {
			$option = $this->data->bookedOptions[$bookedOption];
			for ($i = 1; $i <= $group->eventOptions[$bookedOption]->booking_limit; $i++) {
				$checked = ($option->getValue() == $i ? " checked" : "");
				$disabled = "";
				if ($option->person_limit > 0 && $option->person_limit < $option->no_of_bookings + $i && !$allFields) $disabled = " disabled";
				echo "    <option value=\"{$i}\"{$checked}{$disabled}>{$i} " . ($i > 1 ? _("tickets") : _("ticket")) . "</option>\n";
			}
		}
		echo "  </select>\n";
	}

	private function printAddInfo(EventOptionsGroup $group, EventOption $option, $readonly = "") {
		$classes = array();
		if ($group->required) $classes[] = "required";
		if (!$this->data->validation->isValid("event_option[{$option->event_option_id}]")) $classes[] = "error";
		$classes = $this->getClassString($classes);
		echo "  <label {$classes}for=\"event_option_{$option->event_option_id}\">{$option->event_option}:</label>\n";
		if (isset($this->data->bookedOptions[$option->event_option_id]))
			$value = $this->data->bookedOptions[$option->event_option_id]->getValue(true);
		else
			$value = "";
		switch ($option->option_type) {
			case EVENT_OPTION_TEXT :
				echo "  <input {$classes}type=\"text\" name=\"event_option[{$option->event_option_id}]\" id=\"event_option[{$option->event_option_id}]\" value=\"{$value}\"{$readonly}>";
				break;
			case EVENT_OPTION_TEXT_MULTILINE :
				echo "  <textarea {$classes}name=\"event_option[{$option->event_option_id}]\" id=\"event_option[{$option->event_option_id}]\"{$readonly}>{$value}</textarea>";
				break;
			case EVENT_OPTION_DATE :
				echo "  <input {$classes}type=\"text\" name=\"event_option[{$option->event_option_id}]\" id=\"event_option[{$option->event_option_id}]\" value=\"{$value}\" placeholder=\"" . CWFTools::dateISO2Local("2000-12-31", getenv("LC_ALL")) . "\"{$readonly}>";
				break;
			case EVENT_OPTION_NUMBER_INT :
				echo "  <input {$classes}type=\"text\" name=\"event_option[{$option->event_option_id}]\" id=\"event_option[{$option->event_option_id}]\" value=\"{$value}\" placeholder=\"" . _("Whole number, e.g. ") . strval(12) . "\"{$readonly}>";
				break;
			case EVENT_OPTION_NUMBER_DEC :
				echo "  <input {$classes}type=\"text\" name=\"event_option[{$option->event_option_id}]\" id=\"event_option[{$option->event_option_id}]\" value=\"{$value}\" placeholder=\"" . _("Decimal number, e.g. ") . CWFTools::float2String(12.3, getenv("LC_ALL")) . "\"{$readonly}>";
				break;
			case EVENT_OPTION_SELECT :
				echo "  <select {$classes} name=\"event_option[{$option->event_option_id}]\" id=\"event_option[{$option->event_option_id}]\"{$readonly}><option></option>";
				foreach($option->list as $entry) {
					if($entry==$value)
						echo "<option selected>{$entry}</option>";
					else
						echo "<option>{$entry}</option>";
				}
				echo "</select>";
				break;
		}
		if (!$this->data->validation->isValid("event_option[{$option->event_option_id}]")) echo "\n  <label for=\"event_option[{$option->event_option_id}]\" class=\"invalid\">{$this->data->validation->getInvalidMessage("event_option[{$option->event_option_id}]")}</label>";
		echo "<br>\n";
  }
}
?>
